@@ -1966,7 +1966,7 @@ class DataflowFlowProfileTcp(OpenApiObject):
     __slots__ = ('_parent')
 
     _TYPES = {
-        'congestionAlgorithm': {
+        'congestion_algorithm': {
             'type': str,
             'enum': [
                 'bbr',
@@ -1976,16 +1976,16 @@ class DataflowFlowProfileTcp(OpenApiObject):
             ],
         },
         'initcwnd': {'type': int},
-        'sendBuf': {'type': int},
-        'receiveBuf': {'type': int},
-        'destinationPort': {'type': 'L4PortRange'},
-        'sourcePort': {'type': 'L4PortRange'},
+        'send_buf': {'type': int},
+        'receive_buf': {'type': int},
+        'destination_port': {'type': 'L4PortRange'},
+        'source_port': {'type': 'L4PortRange'},
     } # type: Dict[str, str]
 
     _REQUIRED= () # type: tuple(str)
 
     _DEFAULTS = {
-        'congestionAlgorithm': 'cubic',
+        'congestion_algorithm': 'cubic',
     } # type: Dict[str, Union(type)]
 
     BBR = 'bbr' # type: str
@@ -1993,34 +1993,34 @@ class DataflowFlowProfileTcp(OpenApiObject):
     CUBIC = 'cubic' # type: str
     RENO = 'reno' # type: str
 
-    def __init__(self, parent=None, congestionAlgorithm='cubic', initcwnd=None, sendBuf=None, receiveBuf=None):
+    def __init__(self, parent=None, congestion_algorithm='cubic', initcwnd=None, send_buf=None, receive_buf=None):
         super(DataflowFlowProfileTcp, self).__init__()
         self._parent = parent
-        self._set_property('congestionAlgorithm', congestionAlgorithm)
+        self._set_property('congestion_algorithm', congestion_algorithm)
         self._set_property('initcwnd', initcwnd)
-        self._set_property('sendBuf', sendBuf)
-        self._set_property('receiveBuf', receiveBuf)
+        self._set_property('send_buf', send_buf)
+        self._set_property('receive_buf', receive_buf)
 
     @property
-    def congestionAlgorithm(self):
+    def congestion_algorithm(self):
         # type: () -> Union[Literal["bbr"], Literal["cubic"], Literal["dctcp"], Literal["reno"]]
-        """congestionAlgorithm getter
+        """congestion_algorithm getter
 
         The TCP congestion algorithm:. bbr - Bottleneck Bandwidth and Round-trip propagation time. dctcp - Data center TCP. cubic - cubic window increase function. reno - TCP New Reno
 
         Returns: Union[Literal["bbr"], Literal["cubic"], Literal["dctcp"], Literal["reno"]]
         """
-        return self._get_property('congestionAlgorithm')
+        return self._get_property('congestion_algorithm')
 
-    @congestionAlgorithm.setter
-    def congestionAlgorithm(self, value):
-        """congestionAlgorithm setter
+    @congestion_algorithm.setter
+    def congestion_algorithm(self, value):
+        """congestion_algorithm setter
 
         The TCP congestion algorithm:. bbr - Bottleneck Bandwidth and Round-trip propagation time. dctcp - Data center TCP. cubic - cubic window increase function. reno - TCP New Reno
 
         value: Union[Literal["bbr"], Literal["cubic"], Literal["dctcp"], Literal["reno"]]
         """
-        self._set_property('congestionAlgorithm', value)
+        self._set_property('congestion_algorithm', value)
 
     @property
     def initcwnd(self):
@@ -2044,68 +2044,68 @@ class DataflowFlowProfileTcp(OpenApiObject):
         self._set_property('initcwnd', value)
 
     @property
-    def sendBuf(self):
+    def send_buf(self):
         # type: () -> int
-        """sendBuf getter
+        """send_buf getter
 
         send buffer size
 
         Returns: int
         """
-        return self._get_property('sendBuf')
+        return self._get_property('send_buf')
 
-    @sendBuf.setter
-    def sendBuf(self, value):
-        """sendBuf setter
+    @send_buf.setter
+    def send_buf(self, value):
+        """send_buf setter
 
         send buffer size
 
         value: int
         """
-        self._set_property('sendBuf', value)
+        self._set_property('send_buf', value)
 
     @property
-    def receiveBuf(self):
+    def receive_buf(self):
         # type: () -> int
-        """receiveBuf getter
+        """receive_buf getter
 
         receive buffer size
 
         Returns: int
         """
-        return self._get_property('receiveBuf')
+        return self._get_property('receive_buf')
 
-    @receiveBuf.setter
-    def receiveBuf(self, value):
-        """receiveBuf setter
+    @receive_buf.setter
+    def receive_buf(self, value):
+        """receive_buf setter
 
         receive buffer size
 
         value: int
         """
-        self._set_property('receiveBuf', value)
+        self._set_property('receive_buf', value)
 
     @property
-    def destinationPort(self):
+    def destination_port(self):
         # type: () -> L4PortRange
-        """destinationPort getter
+        """destination_port getter
 
         Layer4 protocol source or destination port valuesLayer4 protocol source or destination port values
 
         Returns: L4PortRange
         """
-        return self._get_property('destinationPort', L4PortRange)
+        return self._get_property('destination_port', L4PortRange)
 
     @property
-    def sourcePort(self):
+    def source_port(self):
         # type: () -> L4PortRange
-        """sourcePort getter
+        """source_port getter
 
         Layer4 protocol source or destination port valuesLayer4 protocol source or destination port values
 
         Returns: L4PortRange
         """
-        return self._get_property('sourcePort', L4PortRange)
+        return self._get_property('source_port', L4PortRange)
 
 
 class L4PortRange(OpenApiObject):
@@ -2441,7 +2441,10 @@ class MetricsResponse(OpenApiObject):
     __slots__ = ('_parent')
 
     _TYPES = {
-        'jct': {'type': float},
+        'jct': {
+            'type': int,
+            'format': 'int64',
+        },
         'flow_results': {'type': 'MetricsResponseFlowResultIter'},
     } # type: Dict[str, str]
 
@@ -2456,12 +2459,12 @@ class MetricsResponse(OpenApiObject):
 
     @property
     def jct(self):
-        # type: () -> float
+        # type: () -> int
         """jct getter
 
         job completion time in micro seconds
 
-        Returns: float
+        Returns: int
         """
         return self._get_property('jct')
 
@@ -2471,7 +2474,7 @@ class MetricsResponse(OpenApiObject):
 
         job completion time in micro seconds
 
-        value: float
+        value: int
         """
         self._set_property('jct', value)
 
@@ -2492,14 +2495,32 @@ class MetricsResponseFlowResult(OpenApiObject):
 
     _TYPES = {
         'workload_name': {'type': str},
-        'flow_number': {'type': int},
+        'flow_number': {
+            'type': int,
+            'format': 'int64',
+        },
         'from_host_name': {'type': str},
         'to_host_name': {'type': str},
-        'fct': {'type': float},
-        'first_timestamp': {'type': int},
-        'last_timestamp': {'type': int},
-        'bytes_tx': {'type': int},
-        'bytes_rx': {'type': int},
+        'fct': {
+            'type': int,
+            'format': 'int64',
+        },
+        'first_timestamp': {
+            'type': int,
+            'format': 'int64',
+        },
+        'last_timestamp': {
+            'type': int,
+            'format': 'int64',
+        },
+        'bytes_tx': {
+            'type': int,
+            'format': 'int64',
+        },
+        'bytes_rx': {
+            'type': int,
+            'format': 'int64',
+        },
         'tcp_info': {'type': 'MetricsResponseFlowResultTcpInfo'},
     } # type: Dict[str, str]
 
@@ -2606,12 +2627,12 @@ class MetricsResponseFlowResult(OpenApiObject):
 
     @property
     def fct(self):
-        # type: () -> float
+        # type: () -> int
         """fct getter
 
         flow completion time in micro seconds
 
-        Returns: float
+        Returns: int
         """
         return self._get_property('fct')
 
@@ -2621,7 +2642,7 @@ class MetricsResponseFlowResult(OpenApiObject):
 
         flow completion time in micro seconds
 
-        value: float
+        value: int
         """
         self._set_property('fct', value)
 
@@ -2725,9 +2746,18 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
     __slots__ = ('_parent')
 
     _TYPES = {
-        'rtt': {'type': float},
-        'rtt_variance': {'type': float},
-        'retransmissions': {'type': float},
+        'rtt': {
+            'type': int,
+            'format': 'int64',
+        },
+        'rtt_variance': {
+            'type': int,
+            'format': 'int64',
+        },
+        'retransmissions': {
+            'type': int,
+            'format': 'int64',
+        },
     } # type: Dict[str, str]
 
     _REQUIRED= () # type: tuple(str)
@@ -2743,12 +2773,12 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
 
     @property
     def rtt(self):
-        # type: () -> float
+        # type: () -> int
         """rtt getter
 
         round trip time in microseconds
 
-        Returns: float
+        Returns: int
         """
         return self._get_property('rtt')
 
@@ -2758,18 +2788,18 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
 
         round trip time in microseconds
 
-        value: float
+        value: int
         """
         self._set_property('rtt', value)
 
     @property
     def rtt_variance(self):
-        # type: () -> float
+        # type: () -> int
         """rtt_variance getter
 
         round trip time variance in microseconds, larger values indicate less stable performance
 
-        Returns: float
+        Returns: int
         """
         return self._get_property('rtt_variance')
 
@@ -2779,18 +2809,18 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
 
         round trip time variance in microseconds, larger values indicate less stable performance
 
-        value: float
+        value: int
         """
         self._set_property('rtt_variance', value)
 
     @property
     def retransmissions(self):
-        # type: () -> float
+        # type: () -> int
         """retransmissions getter
 
         total number of TCP retransmissions
 
-        Returns: float
+        Returns: int
         """
         return self._get_property('retransmissions')
 
@@ -2800,7 +2830,7 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
 
         total number of TCP retransmissions
 
-        value: float
+        value: int
         """
         self._set_property('retransmissions', value)
 
@@ -2832,7 +2862,7 @@ class MetricsResponseFlowResultIter(OpenApiIter):
         return self._next()
 
     def flowresult(self, workload_name=None, flow_number=None, from_host_name=None, to_host_name=None, fct=None, first_timestamp=None, last_timestamp=None, bytes_tx=None, bytes_rx=None):
-        # type: (str,int,str,str,float,int,int,int,int) -> MetricsResponseFlowResultIter
+        # type: (str,int,str,str,int,int,int,int,int) -> MetricsResponseFlowResultIter
         """Factory method that creates an instance of the MetricsResponseFlowResult class
 
         result for a single data flow
@@ -2844,7 +2874,7 @@ class MetricsResponseFlowResultIter(OpenApiIter):
         return self
 
     def add(self, workload_name=None, flow_number=None, from_host_name=None, to_host_name=None, fct=None, first_timestamp=None, last_timestamp=None, bytes_tx=None, bytes_rx=None):
-        # type: (str,int,str,str,float,int,int,int,int) -> MetricsResponseFlowResult
+        # type: (str,int,str,str,int,int,int,int,int) -> MetricsResponseFlowResult
         """Add method that creates and returns an instance of the MetricsResponseFlowResult class
 
         result for a single data flow
